@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,6 +50,7 @@
 
 /* -- path_list_async_new implementation -- */
 
+
 PathListData * 
 path_list_data_new ()
 {
@@ -116,6 +117,8 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 	pli->result = result;
 
 	if (pli->interrupted) {
+		gnome_vfs_async_cancel (handle);
+		pli->interrupted = FALSE;
 		if (pli->interrupt_func) 
 			pli->interrupt_func (pli->interrupt_data);
 		path_list_data_free (pli);
@@ -298,15 +301,16 @@ typedef struct {
 	gpointer data;
 	GList *dirs;
 	GList *visited_dirs;
+	gboolean interrupted;
 } VisitRCDirData;
 
 
-VisitRCDirData *
+static VisitRCDirData *
 visit_rc_dir_data_new ()
 {
 	VisitRCDirData * rcd;
 
-	rcd = g_new (VisitRCDirData, 1);
+	rcd = g_new0 (VisitRCDirData, 1);
 	rcd->dirs = NULL;
 	rcd->visited_dirs = NULL;
 
@@ -314,7 +318,7 @@ visit_rc_dir_data_new ()
 }
 
 
-void
+static void
 visit_rc_dir_data_free (VisitRCDirData *rcd)
 {
 	if (rcd == NULL)
@@ -372,9 +376,12 @@ rc_path_list_done_cb (PathListData *pld,
 			(* rcd->do_something) (real_file, rc_file, rcd->data);
 
 		g_free (real_file);
+
+		if (rcd->interrupted)
+			break;
 	}
 
-	if (! rcd->recursive) {
+	if (! rcd->recursive || rcd->interrupted) {
 		if (rcd->done_func)
 			(* rcd->done_func) (rcd->visited_dirs, rcd->data);
 		path_list_data_free (pld);
@@ -689,13 +696,13 @@ set_file_mtime (const gchar *path,
 
 
 gboolean 
-file_copy (const gchar *from, 
-	   const gchar *to)
+file_copy (const char *from, 
+	   const char *to)
 {
 	FILE *fin, *fout;
-	gchar buf[BUF_SIZE];
-	gchar *dest_dir;
-	gint  n;
+	char  buf[BUF_SIZE];
+	char *dest_dir;
+	int   n;
 
 	if (strcmp (from, to) == 0) {
 		g_warning ("cannot copy file %s: source and destination are the same\n", from);
@@ -874,7 +881,7 @@ image_is_jpeg (const char *name)
 {
 	const char *result;
 
-	if (eel_gconf_get_boolean (PREF_FAST_FILE_TYPE))
+	if (eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE))
 		result = gnome_vfs_mime_type_from_name_or_default (name, NULL);
 	else 
 		result = gnome_vfs_get_file_mime_type (name, NULL, FALSE);
