@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #define ADD_LIST_DELAY 30
 #define ADD_LIST_CHUNK 400
 #define SCROLL_DELAY   20
+#define DEF_THUMB_SIZE 128
 
 enum {
 	BUSY,
@@ -118,22 +119,12 @@ load_thumb_done_cb (ThumbLoader *tl,
 }
 
 
-static void
-free_file_data_list (GList *list)
-{
-	GList *scan;
-	for (scan = list; scan; scan = scan->next) 
-		file_data_unref (scan->data);
-	g_list_free (list);
-}
-
-
 static void
 gth_file_list_free_list (GthFileList *file_list)
 {
 	g_return_if_fail (file_list != NULL);
 
-	free_file_data_list (file_list->list);
+	file_data_list_free (file_list->list);
 	file_list->list = NULL;
 }
 
@@ -241,16 +232,15 @@ gth_file_list_init (GthFileList *file_list)
 {
 	GtkAdjustment  *adj;
 	GtkWidget      *scrolled_window;
-	GthViewMode     view_mode;
 
 	/* set the default values. */
 
 	file_list->list              = NULL;
 	file_list->sort_method       = pref_get_arrange_type ();
 	file_list->sort_type         = pref_get_sort_order ();
-	file_list->show_dot_files    = eel_gconf_get_boolean (PREF_SHOW_HIDDEN_FILES);
-	file_list->enable_thumbs     = eel_gconf_get_boolean (PREF_SHOW_THUMBNAILS);
-	file_list->thumb_size        = eel_gconf_get_integer (PREF_THUMBNAIL_SIZE);
+	file_list->show_dot_files    = eel_gconf_get_boolean (PREF_SHOW_HIDDEN_FILES, FALSE);
+	file_list->enable_thumbs     = eel_gconf_get_boolean (PREF_SHOW_THUMBNAILS, TRUE);
+	file_list->thumb_size        = eel_gconf_get_integer (PREF_THUMBNAIL_SIZE, DEF_THUMB_SIZE);
 	file_list->doing_thumbs      = FALSE;
 	file_list->thumb_loader      = THUMB_LOADER (thumb_loader_new (NULL, file_list->thumb_size, file_list->thumb_size));
 	file_list->thumbs_num        = 0;
@@ -278,21 +268,17 @@ gth_file_list_init (GthFileList *file_list)
 	/* image list. */
 
 	if (pref_get_view_as () == GTH_VIEW_AS_THUMBNAILS)
-		file_list->view = gth_file_view_thumbs_new (eel_gconf_get_integer (PREF_THUMBNAIL_SIZE) + THUMB_BORDER);
+		file_list->view = gth_file_view_thumbs_new (eel_gconf_get_integer (PREF_THUMBNAIL_SIZE, DEF_THUMB_SIZE) + THUMB_BORDER);
 
 	else if (pref_get_view_as () == GTH_VIEW_AS_LIST)
-		file_list->view = gth_file_view_list_new (eel_gconf_get_integer (PREF_THUMBNAIL_SIZE) + THUMB_BORDER);
+		file_list->view = gth_file_view_list_new (eel_gconf_get_integer (PREF_THUMBNAIL_SIZE, DEF_THUMB_SIZE) + THUMB_BORDER);
 
 	gth_file_view_enable_thumbs (file_list->view, file_list->enable_thumbs);
 
 	gth_file_view_set_image_width (file_list->view, file_list->thumb_size + THUMB_BORDER);
 	gth_file_view_sorted (file_list->view, file_list->sort_method, file_list->sort_type);
 
-	if (eel_gconf_get_boolean (PREF_SHOW_COMMENTS))
-		view_mode = GTH_VIEW_MODE_ALL;
-	else
-		view_mode = GTH_VIEW_MODE_LABEL;
-	gth_file_view_set_view_mode (file_list->view, view_mode);
+	gth_file_view_set_view_mode (file_list->view, pref_get_view_mode ());
 
 	/**/
 
@@ -406,12 +392,7 @@ get_file_info_data_free (GetFileInfoData *data)
 		g_list_free (data->uri_list);
 	}
 
-	if (data->filtered != NULL) {
-		g_list_foreach (data->filtered, 
-				(GFunc) file_data_unref, 
-				NULL);
-		g_list_free (data->filtered);
-	}
+	file_data_list_free (data->filtered);
 
 	g_free (data);
 }
@@ -431,11 +412,13 @@ set_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 	GetFileInfoData *gfi_data = callback_data;
 	GthFileList     *file_list = gfi_data->file_list;
 	GList           *scan;
-	DoneFunc         done_func;
 
 	g_signal_emit (G_OBJECT (file_list), gth_file_list_signals[IDLE], 0);
 
 	if (file_list->interrupt_set_list) {
+		DoneFunc done_func;
+
+		file_list->interrupt_set_list = FALSE;
 		done_func = file_list->interrupt_done_func;
 		file_list->interrupt_done_func = NULL;
 		if (done_func != NULL)
@@ -450,7 +433,7 @@ set_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 		char                      *escaped;
 		FileData                  *fd;
 
-		if (info_result->result != GNOME_VFS_OK) 
+		if ((info_result->result != GNOME_VFS_OK) || (info_result->uri == NULL))
 			continue;
 
 		escaped = gnome_vfs_uri_to_string (info_result->uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
@@ -463,24 +446,26 @@ set_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 		gfi_data->filtered = g_list_prepend (gfi_data->filtered, fd);
 	}
 
-	gth_file_view_clear (file_list->view);
-
 	add_list_in_chunks (gfi_data);
 }
 
 
-void
+static void
 set_list__step2 (GetFileInfoData *gfi_data)
 {
 	GnomeVFSAsyncHandle *handle;
 	GthFileList         *file_list = gfi_data->file_list;
 
 	if (file_list->interrupt_set_list) {
+		DoneFunc done_func;
+
 		g_signal_emit (G_OBJECT (file_list), gth_file_list_signals[IDLE], 0);
 
-		if (file_list->interrupt_done_func != NULL)
-			(*file_list->interrupt_done_func) (file_list->interrupt_done_data);
+		file_list->interrupt_set_list = FALSE;
+		done_func = file_list->interrupt_done_func;
 		file_list->interrupt_done_func = NULL;
+		if (done_func != NULL)
+			(*done_func) (file_list->interrupt_done_data);
 		get_file_info_data_free (gfi_data);
 		return;
 	}
@@ -511,12 +496,14 @@ gth_file_list_set_list (GthFileList *file_list,
 
 	g_signal_emit (G_OBJECT (file_list), gth_file_list_signals[BUSY], 0);
 
+	gth_file_view_clear (file_list->view); 
+
 	file_list->interrupt_set_list = FALSE;
 	gfi_data = get_file_info_data_new (file_list, 
 					   done_func, 
 					   done_func_data);
 
-	fast_file_type = eel_gconf_get_boolean (PREF_FAST_FILE_TYPE);
+	fast_file_type = eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE);
 
 	for (scan = new_list; scan; scan = scan->next) {
 		char        *full_path = scan->data;
@@ -553,6 +540,12 @@ gth_file_list_interrupt_set_list (GthFileList *file_list,
 {
 	g_return_if_fail (file_list != NULL);
 
+	if (file_list->interrupt_set_list) {
+		if (done_func != NULL)
+			(*done_func) (done_data);
+		return;
+	}
+
 	file_list->interrupt_set_list = TRUE;
 	file_list->interrupt_done_func = done_func;
 	file_list->interrupt_done_data = done_data;
@@ -568,7 +561,6 @@ add_list_in_chunks (gpointer callback_data)
 	GetFileInfoData *gfi_data = callback_data;
 	GthFileList     *file_list = gfi_data->file_list;
 	GList           *scan, *chunk;
-	DoneFunc         done_func;
 	int              i, n = ADD_LIST_CHUNK;
 
 	if (gfi_data->timeout_id != 0) {
@@ -577,8 +569,11 @@ add_list_in_chunks (gpointer callback_data)
 	}
 
 	if (file_list->interrupt_set_list) {
+		DoneFunc  done_func;
+
 		file_list->enable_thumbs = gfi_data->enable_thumbs;
 
+		file_list->interrupt_set_list = FALSE;
 		done_func = file_list->interrupt_done_func;
 		file_list->interrupt_done_func = NULL;
 		if (done_func != NULL)
@@ -590,6 +585,8 @@ add_list_in_chunks (gpointer callback_data)
 	}
 
 	if (gfi_data->filtered == NULL) {
+		DoneFunc  done_func;
+
 		file_list->enable_thumbs = gfi_data->enable_thumbs;
 
 		if ((file_list->list != NULL) && file_list->enable_thumbs) { 
@@ -659,11 +656,12 @@ add_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 				 gpointer callback_data)
 {
 	GetFileInfoData *gfi_data = callback_data;
-	GthFileList        *file_list = gfi_data->file_list;
+	GthFileList     *file_list = gfi_data->file_list;
 	GList           *scan;
-	DoneFunc         done_func;
 
 	if (file_list->interrupt_set_list) {
+		DoneFunc done_func;
+	
 		done_func = file_list->interrupt_done_func;
 		file_list->interrupt_done_func = NULL;
 		if (done_func != NULL)
@@ -697,16 +695,19 @@ add_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 }
 
 
-void
+static void
 add_list__step2 (GetFileInfoData *gfi_data)
 {
 	GnomeVFSAsyncHandle *handle;
-	GthFileList            *file_list = gfi_data->file_list;
+	GthFileList         *file_list = gfi_data->file_list;
 
 	if (file_list->interrupt_set_list) {
-		if (file_list->interrupt_done_func != NULL)
-			(*file_list->interrupt_done_func) (file_list->interrupt_done_data);
+		DoneFunc done_func;
+
+		done_func = file_list->interrupt_done_func;
 		file_list->interrupt_done_func = NULL;
+		if (done_func != NULL)
+			(*done_func) (file_list->interrupt_done_data);
 		get_file_info_data_free (gfi_data);
 		return;
 	}
@@ -748,7 +749,7 @@ gth_file_list_add_list (GthFileList *file_list,
 
 		if ((! gfi_data->file_list->show_dot_files 
 		     && file_is_hidden (name_only))
-		    || ! file_is_image (full_path, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE)))
+		    || ! file_is_image (full_path, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE)))
 			continue;
 		
 		escaped = gnome_vfs_escape_path_string (full_path);
@@ -819,7 +820,7 @@ it_data_free (InterruptThumbsData *it_data)
 /* -- -- */
 
 
-void
+static void
 set_sort_method__step2 (InterruptThumbsData *it_data)
 {
 	GthFileList    *file_list = it_data->file_list;
@@ -866,7 +867,7 @@ gth_file_list_set_sort_method (GthFileList   *file_list,
 /* -- -- */
 
 
-void
+static void
 set_sort_type__step2 (InterruptThumbsData *it_data)
 {
 	GthFileList *file_list = it_data->file_list;
@@ -915,10 +916,13 @@ static void gth_file_list_thumb_cleanup (GthFileList *file_list);
 static void
 interrupt_thumbs__part2 (GthFileList *file_list)
 {
-	DoneFunc done_func = file_list->interrupt_done_func;
+	DoneFunc done_func;
 
 	gth_file_list_thumb_cleanup (file_list);
+
+	done_func = file_list->interrupt_done_func;
 	file_list->interrupt_done_func = NULL;
+
 	if (done_func != NULL)
 		(*done_func) (file_list->interrupt_done_data);
 }
@@ -935,9 +939,9 @@ gth_file_list_interrupt_thumbs (GthFileList *file_list,
 		file_list->interrupt_done_func = done_func;
 		file_list->interrupt_done_data = done_func_data;
 		file_list->doing_thumbs = FALSE;
+
 	} else if (done_func != NULL)
 		(*done_func) (done_func_data);
-		
 }
 
 
@@ -1018,7 +1022,7 @@ gth_file_list_get_selection_length (GthFileList *file_list)
 
 	sel_list = gth_file_view_get_selection (file_list->view);
 	len = g_list_length (sel_list);
-	g_list_free (sel_list);
+	file_data_list_free (sel_list);
 
 	return len;
 }
@@ -1029,6 +1033,7 @@ gth_file_list_path_from_pos (GthFileList *file_list,
 			     int          pos)
 {
 	FileData *fd;
+	char     *retval = NULL;
 
 	g_return_val_if_fail (file_list != NULL, NULL);
 
@@ -1036,11 +1041,11 @@ gth_file_list_path_from_pos (GthFileList *file_list,
 		return NULL;
 
 	fd = gth_file_view_get_image_data (file_list->view, pos);
-
 	if ((fd != NULL) && (fd->path != NULL))
-		return g_strdup (fd->path);
+		retval = g_strdup (fd->path);
+	file_data_unref (fd);
 
-	return NULL;
+	return retval;
 }
 
 
@@ -1163,16 +1168,21 @@ gth_file_list_next_image (GthFileList *file_list,
 	n = gth_file_view_get_images (file_list->view);
 
 	pos++;
-	while (pos < n) {
+	for (; pos < n; pos++) {
 		FileData *fd;
 
 		fd = gth_file_view_get_image_data (file_list->view, pos);
 
-		if ((! without_error || ! fd->error)
-		    && (! only_selected || gth_file_view_pos_is_selected (file_list->view, pos)))
-		    break;
+		if (without_error && fd->error) {
+			file_data_unref (fd);
+			continue;
+		}
+		file_data_unref (fd);
 
-		pos++;
+		if (only_selected && ! gth_file_view_pos_is_selected (file_list->view, pos))
+			continue;
+
+		break;
 	}
 
 	if (pos >= n)
@@ -1191,16 +1201,21 @@ gth_file_list_prev_image (GthFileList *file_list,
 	g_return_val_if_fail (file_list != NULL, -1);
 
 	pos--;
-	while (pos >= 0) {
+	for (; pos >= 0; pos--) {
 		FileData *fd;
 
 		fd = gth_file_view_get_image_data (file_list->view, pos);
 
-		if ((! without_error || ! fd->error)
-		    && (! only_selected || gth_file_view_pos_is_selected (file_list->view, pos)))
-		    break;
+		if (without_error && fd->error) {
+			file_data_unref (fd);
+			continue;
+		}
+		file_data_unref (fd);
 
-		pos--;
+		if (only_selected && ! gth_file_view_pos_is_selected (file_list->view, pos))
+			continue;
+
+		break;
 	}
 
 	if (pos < 0)
@@ -1213,7 +1228,7 @@ gth_file_list_prev_image (GthFileList *file_list,
 /* -- -- */
 
 
-void
+static void
 delete_pos__step2 (InterruptThumbsData *it_data)
 {
 	GthFileList *file_list = it_data->file_list;
@@ -1224,6 +1239,7 @@ delete_pos__step2 (InterruptThumbsData *it_data)
 
 	g_return_if_fail (fd != NULL);
 
+	file_data_unref (fd);
 	file_list->list = g_list_remove (file_list->list, fd);
 	file_data_unref (fd);
 
@@ -1265,7 +1281,7 @@ gth_file_list_delete_pos (GthFileList *file_list,
 /* -- -- */
 
 
-void
+static void
 rename_pos__step2 (InterruptThumbsData *it_data)
 {
 	GthFileList    *file_list = it_data->file_list;
@@ -1279,6 +1295,7 @@ rename_pos__step2 (InterruptThumbsData *it_data)
 
 	/* Set the new name. */
 	gth_file_view_set_image_text (file_list->view, pos, fd->utf8_name);
+	file_data_unref (fd);
 
 	gth_file_view_sorted (file_list->view,
 			      file_list->sort_method,
@@ -1320,7 +1337,7 @@ gth_file_list_rename_pos (GthFileList *file_list,
 /* -- -- */
 
 
-void
+static void
 update_comment__step2 (InterruptThumbsData *it_data)
 {
 	GthFileList   *file_list = it_data->file_list;
@@ -1333,6 +1350,7 @@ update_comment__step2 (InterruptThumbsData *it_data)
 
 	/* Set the new name. */
 	gth_file_view_set_image_comment (file_list->view, pos, fd->comment);
+	file_data_unref (fd);
 
 	if (it_data->restart_thumbs) {
 		file_list->doing_thumbs = TRUE;
@@ -1369,7 +1387,7 @@ gth_file_list_update_comment (GthFileList *file_list,
 /* -- -- */
 
 
-void
+static void
 set_thumbs_size__step2 (InterruptThumbsData *it_data)
 {
 	GthFileList *file_list = it_data->file_list;
@@ -1428,14 +1446,24 @@ gth_file_list_set_thumbs_size (GthFileList *file_list,
 static void
 gth_file_list_update_current_thumb (GthFileList *file_list)
 {
-	gboolean error = TRUE;
+	gboolean  error = TRUE;
+	char     *path;
 
-	if (path_is_file (file_list->thumb_fd->path)) {
-		char *escaped_path;
-		char *escaped_resolved_path;
-		GnomeVFSResult result;
+	if (! file_list->doing_thumbs) {
+		interrupt_thumbs__part2 (file_list);
+		return;
+	}
 
-		escaped_path = gnome_vfs_escape_path_string (file_list->thumb_fd->path);
+	g_return_if_fail (file_list->thumb_fd != NULL);
+
+	path = g_strdup (file_list->thumb_fd->path);
+
+	if (path_is_file (path)) {
+		char           *escaped_path;
+		char           *escaped_resolved_path;
+		GnomeVFSResult  result;
+
+		escaped_path = gnome_vfs_escape_path_string (path);
 
 		result = resolve_all_symlinks (escaped_path, &escaped_resolved_path);
 		if (result == GNOME_VFS_OK) {
@@ -1457,6 +1485,8 @@ gth_file_list_update_current_thumb (GthFileList *file_list)
 		g_free (escaped_path);
 	}
 		
+	g_free (path);
+
 	if (error) /* Error: the file does not exists. */
 		g_signal_emit_by_name (G_OBJECT (file_list->thumb_loader),
 				       "error",
@@ -1475,13 +1505,15 @@ gth_file_list_update_thumb (GthFileList  *file_list,
 		return;
 
 	fd = gth_file_view_get_image_data (file_list->view, pos);
+
 	file_data_update (fd);
 	fd->error = FALSE;
 	fd->thumb = FALSE;
 
 	file_list->thumb_pos = pos;
 	file_list->thumb_fd = fd;
-	
+	file_data_unref (fd);
+
 	gth_file_list_update_current_thumb (file_list);
 }
 
@@ -1490,7 +1522,7 @@ void
 gth_file_list_update_thumb_list (GthFileList  *file_list,
 				 GList        *list)
 {
-	GList        *scan;
+	GList *scan;
 
 	if (! file_list->enable_thumbs)
 		return;
@@ -1506,10 +1538,10 @@ gth_file_list_update_thumb_list (GthFileList  *file_list,
 			continue;
 
 		fd = gth_file_view_get_image_data (file_list->view, pos);
-
 		file_data_update (fd);
 		fd->error = FALSE;
 		fd->thumb = FALSE;
+		file_data_unref (fd);
 	}
 	
 	file_list->doing_thumbs = TRUE;
@@ -1535,11 +1567,11 @@ gth_file_list_thumb_cleanup (GthFileList *file_list)
 static void
 gth_file_list_update_next_thumb (GthFileList *file_list)
 {
-	FileData     *fd = NULL;
-	int           first_pos, last_pos;
-	int           pos = -1;
-	GList        *list, *scan;
-	int           new_pos = -1;
+	FileData *fd = NULL;
+	int       first_pos, last_pos;
+	int       pos = -1;
+	GList    *list, *scan;
+	int       new_pos = -1;
 
 	if (! file_list->doing_thumbs) {
 		interrupt_thumbs__part2 (file_list);
@@ -1595,7 +1627,7 @@ gth_file_list_update_thumbs (GthFileList *file_list)
 	if (! file_list->enable_thumbs)
 		return;
 
-	thumb_loader_set_max_file_size (THUMB_LOADER (file_list->thumb_loader), eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT));
+	thumb_loader_set_max_file_size (THUMB_LOADER (file_list->thumb_loader), eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
 
 	for (scan = file_list->list; scan; scan = scan->next) {
 		FileData *fd = scan->data;
