@@ -70,6 +70,7 @@
 #include "gth-folder-selection-dialog.h"
 
 #define MAX_NAME_LEN 1024
+#define DEF_CONFIRM_DEL TRUE
 
 typedef enum {
 	WALLPAPER_ALIGN_TILED     = 0,
@@ -102,7 +103,7 @@ file_new_window_command_impl (BonoboUIComponent *uic,
 					NULL);	
 
 	if (location != NULL) {
-		eel_gconf_set_locale_string (PREF_STARTUP_LOCATION, location);
+		preferences_set_startup_location (location);
 		g_free (location);
 	}
 
@@ -773,7 +774,7 @@ image_delete_from_catalog_command_impl (BonoboUIComponent *uic,
 	if (window->image_path == NULL)
 		return;
 
-	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, DEF_CONFIRM_DEL)) {
 		list = g_list_prepend (NULL, g_strdup (window->image_path));
 		real_remove_from_catalog (window, list);
 		/* the list is deallocated in real_remove_from_catalog. */
@@ -817,7 +818,7 @@ edit_remove_from_catalog_command_impl (BonoboUIComponent *uic,
 	GtkWidget    *dialog;
 	int           r;
 
-	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, DEF_CONFIRM_DEL)) {
 		remove_selection_from_catalog (window);
 		return;
 	}
@@ -1171,25 +1172,31 @@ folder_delete__continue (GnomeVFSResult result,
 	FolderDeleteData *fddata = data;
 
 	if (result == GNOME_VFS_ERROR_NOT_FOUND) {
-		GtkWidget *d;
-		char      *utf8_name;
-		char      *message;
-		int        r;
+		int r = GTK_RESPONSE_YES;
 
-		utf8_name = g_locale_to_utf8 (file_name_from_path (fddata->path), -1, 0, 0, 0);
-		message = g_strdup_printf (_("\"%s\" cannot be moved to the Trash. Do you want to delete it permanently?"), utf8_name);
+		if (eel_gconf_get_boolean (PREF_MSG_CANNOT_MOVE_TO_TRASH, TRUE)) {
+			GtkWidget *d;
+			char      *utf8_name;
+			char      *message;
 
-		d = _gtk_yesno_dialog_new (GTK_WINDOW (fddata->window->app),
-					   GTK_DIALOG_MODAL,
-					   message,
-					   GTK_STOCK_CANCEL,
-					   GTK_STOCK_DELETE);
+			utf8_name = g_locale_to_utf8 (file_name_from_path (fddata->path), -1, 0, 0, 0);
+			message = g_strdup_printf (_("\"%s\" cannot be moved to the Trash. Do you want to delete it permanently?"), utf8_name);
 
-		g_free (message);
-		g_free (utf8_name);
+			d = _gtk_yesno_dialog_with_checkbutton_new (
+				    GTK_WINDOW (fddata->window->app),
+				    GTK_DIALOG_MODAL,
+				    message,
+				    GTK_STOCK_CANCEL,
+				    GTK_STOCK_DELETE,
+				    _("_Do not display this message again"),
+				    PREF_MSG_CANNOT_MOVE_TO_TRASH);
 
-		r = gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
+			g_free (message);
+			g_free (utf8_name);
+		
+			r = gtk_dialog_run (GTK_DIALOG (d));
+			gtk_widget_destroy (GTK_WIDGET (d));
+		} 
 
 		if (r == GTK_RESPONSE_YES) 
 			dlg_folder_delete (fddata->window, 
@@ -1772,7 +1779,7 @@ catalog_delete (GThumbWindow *window,
 
 	/* Always ask before deleting folders. */
 
-	if (! path_is_dir (catalog_path) && ! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! path_is_dir (catalog_path) && ! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, DEF_CONFIRM_DEL)) {
 		real_catalog_delete (window);
 		return;
 	}
