@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -452,9 +452,9 @@ size_column_sort_func (GtkTreeModel *model,
 
 static int
 n_column_sort_func (GtkTreeModel *model, 
-		       GtkTreeIter  *a, 
-		       GtkTreeIter  *b, 
-		       gpointer      user_data)
+		    GtkTreeIter  *a, 
+		    GtkTreeIter  *b, 
+		    gpointer      user_data)
 {
 	ImageData *idata1, *idata2;
 	int        n1, n2;
@@ -1498,7 +1498,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
 			unesc_uri = gnome_vfs_unescape_string (str_uri, NULL);
 
-			if (file_is_image (unesc_uri, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE)))
+			if (file_is_image (unesc_uri, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, FALSE)))
 				files = g_list_prepend (files, unesc_uri);
 			else
 				g_free (unesc_uri);
