@@ -212,17 +212,23 @@ real_files_delete__continue (GnomeVFSResult result,
 	ConfirmFileDeleteData *cfddata = data;
 
 	if (result == GNOME_VFS_ERROR_NOT_FOUND) {
-		GtkWidget *d;
-		int        r;
+		int r = GTK_RESPONSE_YES;
 
-		d = _gtk_yesno_dialog_new (GTK_WINDOW (cfddata->window->app),
-					   GTK_DIALOG_MODAL,
-					   _("The images cannot be moved to the Trash. Do you want to delete them permanently?"),
-					   GTK_STOCK_CANCEL,
-					   GTK_STOCK_DELETE);
+		if (eel_gconf_get_boolean (PREF_MSG_CANNOT_MOVE_TO_TRASH, TRUE)) {
+			GtkWidget *d;
 
-		r = gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
+			d = _gtk_yesno_dialog_with_checkbutton_new (
+				    GTK_WINDOW (cfddata->window->app),
+				    GTK_DIALOG_MODAL,
+				    _("The images cannot be moved to the Trash. Do you want to delete them permanently?"),
+				    GTK_STOCK_CANCEL,
+				    GTK_STOCK_DELETE,
+				    _("_Do not display this message again"),
+				    PREF_MSG_CANNOT_MOVE_TO_TRASH);
+		
+			r = gtk_dialog_run (GTK_DIALOG (d));
+			gtk_widget_destroy (GTK_WIDGET (d));
+		} 
 
 		if (r == GTK_RESPONSE_YES) 
 			dlg_files_delete (cfddata->window, 
@@ -262,7 +268,7 @@ dlg_file_delete__confirm (GThumbWindow *window,
 	GtkWidget *dialog;
 	int        result;
 
-	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, TRUE)) {
 		real_files_delete (window, list);
 		return TRUE;
 	}
@@ -1038,6 +1044,7 @@ typedef struct {
 	GtkWidget           *progress_dialog;
 	GtkWidget           *progress_progressbar;
 	GtkWidget           *progress_info;
+	GtkWidget           *progress_cancel;
 
 	guint                timeout_id;
 
@@ -1184,6 +1191,7 @@ files_copy__done (FileCopyData *fcdata)
 	if (fcdata->remove_source)
 		all_windows_notify_files_deleted (fcdata->copied_list);
 	all_windows_notify_files_created (fcdata->created_list);
+	all_windows_add_monitor ();
 	
 	if (fcdata->done_func != NULL)
 		(*fcdata->done_func) (fcdata->result, fcdata->done_data);
@@ -1520,6 +1528,32 @@ copy_next_file (FileCopyData *fcdata)
 }
 
 
+static void
+dlg_files_copy__interrupt (FileCopyData *fcdata)
+{
+	if (fcdata->handle != NULL)
+		gnome_vfs_async_cancel (fcdata->handle);
+	files_copy__done (fcdata);
+}
+
+
+static void
+dlg_files_copy__interrupt_cb1 (GtkWidget    *caller, 
+			       GdkEvent     *event, 
+			       FileCopyData *fcdata)
+{
+	dlg_files_copy__interrupt (fcdata);
+}
+
+
+static void
+dlg_files_copy__interrupt_cb2 (GtkWidget    *caller, 
+			       FileCopyData *fcdata)
+{
+	dlg_files_copy__interrupt (fcdata);
+}
+
+
 void
 dlg_files_copy (GThumbWindow   *window,
 		GList          *file_list,
@@ -1530,7 +1564,7 @@ dlg_files_copy (GThumbWindow   *window,
 		FileOpDoneFunc  done_func,
 		gpointer        done_data)
 {
-	FileCopyData              *fcdata;
+	FileCopyData *fcdata;
 
 	if (! path_is_dir (dest_path))
 		return;
@@ -1577,6 +1611,16 @@ dlg_files_copy (GThumbWindow   *window,
 	fcdata->progress_dialog = glade_xml_get_widget (fcdata->gui, "progress_dialog");
 	fcdata->progress_progressbar = glade_xml_get_widget (fcdata->gui, "progress_progressbar");
 	fcdata->progress_info = glade_xml_get_widget (fcdata->gui, "progress_info");
+	fcdata->progress_cancel = glade_xml_get_widget (fcdata->gui, "progress_cancel");
+
+	g_signal_connect (G_OBJECT (fcdata->progress_dialog), 
+			  "delete_event",
+			  G_CALLBACK (dlg_files_copy__interrupt_cb1),
+			  fcdata);
+	g_signal_connect (G_OBJECT (fcdata->progress_cancel), 
+			  "clicked",
+			  G_CALLBACK (dlg_files_copy__interrupt_cb2),
+			  fcdata);
 
 	gtk_window_set_transient_for (GTK_WINDOW (fcdata->progress_dialog),
 				      GTK_WINDOW (fcdata->window->app));
@@ -1586,6 +1630,8 @@ dlg_files_copy (GThumbWindow   *window,
 					    file_copy__display_progress_dialog,
 					    fcdata);
 
+	all_windows_remove_monitor ();
+
 	copy_current_file (fcdata);
 }
 
@@ -1644,6 +1690,7 @@ typedef struct {
 	GtkWidget           *progress_dialog;
 	GtkWidget           *progress_progressbar;
 	GtkWidget           *progress_info;
+	GtkWidget           *progress_cancel;
 
 	GThumbWindow        *window;
 	GList               *file_list;
@@ -1694,8 +1741,11 @@ file_delete__display_progress_dialog (gpointer data)
 static void
 files_delete__done (FileDeleteData *fddata)
 {
-	if (fddata->result == GNOME_VFS_OK)
+	if (fddata->result == GNOME_VFS_OK) 
 		all_windows_notify_files_deleted (fddata->file_list);
+	else
+		all_windows_notify_files_changed (fddata->file_list);
+	all_windows_add_monitor ();
 	
 	if (fddata->done_func != NULL)
 		(*fddata->done_func) (fddata->result, fddata->done_data);
@@ -1743,6 +1793,32 @@ file_delete_progress_update_cb (GnomeVFSAsyncHandle      *handle,
 }
 
 
+static void
+dlg_files_delete__interrupt (FileDeleteData *fcdata)
+{
+	if (fcdata->handle != NULL)
+		gnome_vfs_async_cancel (fcdata->handle);
+	files_delete__done (fcdata);
+}
+
+
+static void
+dlg_files_delete__interrupt_cb1 (GtkWidget      *caller, 
+				 GdkEvent       *event, 
+				 FileDeleteData *fcdata)
+{
+	dlg_files_delete__interrupt (fcdata);
+}
+
+
+static void
+dlg_files_delete__interrupt_cb2 (GtkWidget      *caller, 
+				 FileDeleteData *fcdata)
+{
+	dlg_files_delete__interrupt (fcdata);
+}
+
+
 void
 dlg_files_delete (GThumbWindow   *window,
 		  GList          *file_list,
@@ -1780,6 +1856,16 @@ dlg_files_delete (GThumbWindow   *window,
 	fddata->progress_dialog = glade_xml_get_widget (fddata->gui, "progress_dialog");
 	fddata->progress_progressbar = glade_xml_get_widget (fddata->gui, "progress_progressbar");
 	fddata->progress_info = glade_xml_get_widget (fddata->gui, "progress_info");
+	fddata->progress_cancel = glade_xml_get_widget (fddata->gui, "progress_cancel");
+
+	g_signal_connect (G_OBJECT (fddata->progress_dialog), 
+			  "delete_event",
+			  G_CALLBACK (dlg_files_delete__interrupt_cb1),
+			  fddata);
+	g_signal_connect (G_OBJECT (fddata->progress_cancel), 
+			  "clicked",
+			  G_CALLBACK (dlg_files_delete__interrupt_cb2),
+			  fddata);
 	
 	gtk_window_set_transient_for (GTK_WINDOW (fddata->progress_dialog),
 				      GTK_WINDOW (fddata->window->app));
@@ -1791,6 +1877,8 @@ dlg_files_delete (GThumbWindow   *window,
 
 	/**/
 
+	all_windows_remove_monitor ();
+
 	for (scan = fddata->file_list; scan; scan = scan->next) {
 		const char  *path = scan->data;
 		GnomeVFSURI *uri;
@@ -1850,6 +1938,7 @@ typedef struct {
 	GtkWidget           *progress_dialog;
 	GtkWidget           *progress_progressbar;
 	GtkWidget           *progress_info;
+	GtkWidget           *progress_cancel;
 
 	GnomeVFSAsyncHandle *handle;
 	GnomeVFSResult       result;
@@ -1874,6 +1963,8 @@ destroy_progress_dialog (FolderCopyData *fcdata)
 static void
 folder_copy_data_free (FolderCopyData *fcdata)
 {
+	all_windows_add_monitor ();
+
 	if (fcdata == NULL)
 		return;
 
@@ -1947,7 +2038,6 @@ folder_progress_update_cb (GnomeVFSAsyncHandle      *handle,
 
 	if (info->bytes_total != 0) {
 		fraction = (float) info->file_index / info->files_total;
-		fraction /= 2.0;
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (fcdata->progress_progressbar), fraction);
 	}
 
@@ -1991,6 +2081,32 @@ folder_copy__display_progress_dialog (gpointer data)
 }
 
 
+static void
+folder_copy__interrupt (FolderCopyData *fcdata)
+{
+	if (fcdata->handle != NULL)
+		gnome_vfs_async_cancel (fcdata->handle);
+	folder_copy_data_free (fcdata);
+}
+
+
+static void
+folder_copy__interrupt_cb1 (GtkWidget     *caller, 
+			    GdkEvent       *event, 
+			    FolderCopyData *fcdata)
+{
+	folder_copy__interrupt (fcdata);
+}
+
+
+static void
+folder_copy__interrupt_cb2 (GtkWidget      *caller, 
+			    FolderCopyData *fcdata)
+{
+	folder_copy__interrupt (fcdata);
+}
+
+
 static void
 folder_copy (GThumbWindow   *window,
 	     const char     *src_path,
@@ -2043,6 +2159,16 @@ folder_copy (GThumbWindow   *window,
 	fcdata->progress_dialog = glade_xml_get_widget (fcdata->gui, "progress_dialog");
 	fcdata->progress_progressbar = glade_xml_get_widget (fcdata->gui, "progress_progressbar");
 	fcdata->progress_info = glade_xml_get_widget (fcdata->gui, "progress_info");
+	fcdata->progress_cancel = glade_xml_get_widget (fcdata->gui, "progress_cancel");
+
+	g_signal_connect (G_OBJECT (fcdata->progress_dialog), 
+			  "delete_event",
+			  G_CALLBACK (folder_copy__interrupt_cb1),
+			  fcdata);
+	g_signal_connect (G_OBJECT (fcdata->progress_cancel), 
+			  "clicked",
+			  G_CALLBACK (folder_copy__interrupt_cb2),
+			  fcdata);
 	
 	gtk_window_set_transient_for (GTK_WINDOW (fcdata->progress_dialog),
 				      GTK_WINDOW (fcdata->window->app));
@@ -2054,6 +2180,8 @@ folder_copy (GThumbWindow   *window,
 
 	/**/
 
+	all_windows_remove_monitor ();
+
 	src_list = g_list_append (src_list, new_uri_from_path (src_path));
 
 	if (fcdata->file_op != FILE_OP_DELETE)
