@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 #include "gth-pixbuf-op.h"
 #include "gthumb-preloader.h"
 
-#define GCONF_NOTIFICATIONS 17
+#define GCONF_NOTIFICATIONS 18
 
 
 typedef enum {
@@ -75,25 +75,47 @@ typedef struct {
 	GtkWidget          *viewer_vscr;
 	GtkWidget          *viewer_hscr;
 	GtkWidget          *viewer_event_box;
-	GtkWidget          *info_bar;
 	GtkWidget          *go_back_combo_button;
 	GtkWidget          *popup_menu;
 
+	GtkWidget          *image_comment;
+	GtkWidget          *image_exif_view;
+	GtkListStore       *image_exif_model;
+
 	GtkWidget          *progress;              /* statusbar widgets. */
 	GtkWidget          *image_info;
 	GtkWidget          *image_info_frame;
+	GtkWidget          *zoom_info;
+	GtkWidget          *zoom_info_frame;
 
 	GtkWidget          *image_prop_dlg;        /* no-modal dialogs. */
 	GtkWidget          *comments_dlg;
 	GtkWidget          *categories_dlg;
 	GtkWidget          *bookmarks_dlg;
 
+	GtkWidget          *info_bar;
+	GtkWidget          *info_combo;
+	GtkWidget          *info_icon;
+
 	char                sidebar_content;       /* SidebarContent values. */
 	int                 sidebar_width;
 	gboolean            sidebar_visible;
 	guint               layout_type : 2;
+
 	gboolean            image_pane_visible;
-	gboolean            image_preview_visible;
+
+	GtkWidget          *preview_widget_image;
+	GtkWidget          *preview_widget_data_comment;
+	GtkWidget          *preview_widget_data;
+	GtkWidget          *preview_widget_comment;
+
+	GtkWidget          *preview_button_image;
+	GtkWidget          *preview_button_data;
+	GtkWidget          *preview_button_comment;
+
+	gboolean            preview_visible;
+	GthPreviewContent   preview_content;
+	gboolean            image_data_visible;
 
 	/* bookmarks & history */
 
@@ -127,7 +149,9 @@ typedef struct {
 						 * is present. */
 	gboolean            image_modified;
 	gboolean            setting_file_list;
+	gboolean            can_set_file_list;
 	gboolean            changing_directory;
+	gboolean            can_change_directory;
 	gboolean            refreshing;         /* true if we are refreshing
 						 * the file list.  Used to 
 						 * handle the refreshing case 
@@ -137,6 +161,8 @@ typedef struct {
 	guint               load_dir_timeout;
 	guint               sel_change_timeout;
 	guint               busy_cursor_timeout;
+	guint               auto_load_timeout;
+	guint               update_layout_timeout;
 
 	GThumbPreloader    *preloader;
 
@@ -169,6 +195,8 @@ typedef struct {
 	GtkWidget             *progress_progressbar;
 	GtkWidget             *progress_info;
 	guint                  progress_timeout;
+
+	GtkTooltips           *tooltips;
 } GThumbWindow;
 
 
@@ -187,6 +215,9 @@ void            window_hide_image_pane              (GThumbWindow *window);
 
 void            window_show_image_pane              (GThumbWindow *window);
 
+void            window_set_preview_content          (GThumbWindow      *window,
+						     GthPreviewContent  content);
+
 void            window_stop_loading                 (GThumbWindow *window);
 
 void            window_refresh                      (GThumbWindow *window);
@@ -231,9 +262,11 @@ void            window_stop_slideshow               (GThumbWindow *window);
 
 void            window_show_image_prop              (GThumbWindow *window);
 
-void            window_image_modified               (GThumbWindow *window,
+void            window_image_set_modified           (GThumbWindow *window,
 						     gboolean      modified);
 
+gboolean        window_image_get_modified           (GThumbWindow *window);
+
 /* functions used to notify a change. */
 
 void            window_notify_files_created         (GThumbWindow *window,
@@ -299,8 +332,6 @@ void            window_add_monitor                  (GThumbWindow *window);
 
 void            window_remove_monitor               (GThumbWindow *window);
 
-void            window_sync_menu_with_preferences   (GThumbWindow *window);
-
 void            window_exec_pixbuf_op               (GThumbWindow *window,
 						     GthPixbufOp  *pixop);
 
