@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -56,9 +56,11 @@ int                  StartSlideshow;
 int                  ViewFirstImage = FALSE;
 int                  HideSidebar = FALSE;
 gboolean             ExitAll = FALSE;
+char                *ImageToDisplay = NULL;
 
 
 static gboolean        view_comline_catalog = FALSE;
+static gboolean        view_single_image = FALSE;
 static GdkPixbuf      *folder_pixbuf = NULL;
 static GThumbWindow   *first_window = NULL;
 static GnomeIconTheme *icon_theme = NULL;
@@ -279,10 +281,8 @@ initialize_data (poptContext pctx)
 
 		if (path_is_dir (path))
 			is_dir = TRUE;
-
 		else if (path_is_file (path))
 			is_dir = FALSE;
-
 		else {
 			g_free (path);
 			continue;
@@ -297,7 +297,10 @@ initialize_data (poptContext pctx)
 			file_urls[n_file_urls++] = path;
 	}
 
-	if (n_file_urls > 0) {
+	if ((n_file_urls == 1) && (file_urls[0] != NULL)) {
+		view_single_image = TRUE;
+
+	} else if (n_file_urls > 1) {
 		/* Create a catalog with the command line list. */
 		Catalog *catalog;
 		char    *catalog_path;
@@ -366,7 +369,23 @@ prepare_app ()
 			first_window = current_window;
 	}
 
-	if (view_comline_catalog) {
+	if (view_single_image) {
+		char *image_folder;
+
+		ImageToDisplay = g_strdup (file_urls[0]);
+		HideSidebar = TRUE;
+
+		image_folder = remove_level_from_path (ImageToDisplay);
+		preferences_set_startup_location (image_folder);
+		g_free (image_folder);
+
+		current_window = window_new ();
+		gtk_widget_show (current_window->app);
+
+		if (first_window == NULL)
+			first_window = current_window;
+
+	} else if (view_comline_catalog) {
 		char *catalog_uri;
 		char *catalog_path;
 		char *catalog_name;
@@ -378,12 +397,12 @@ prepare_app ()
 		catalog_uri = g_strconcat ("catalog://", catalog_path, NULL);
 		g_free (catalog_path);
 
-		eel_gconf_set_locale_string (PREF_STARTUP_LOCATION, catalog_uri);
-
+		preferences_set_startup_location (catalog_uri);
 		g_free (catalog_uri);
 
 		ViewFirstImage = TRUE;
 		HideSidebar = TRUE;
+
 		current_window = window_new ();
 		gtk_widget_show (current_window->app);
 
@@ -393,7 +412,7 @@ prepare_app ()
 
 	for (i = 0; i < n_dir_urls; i++) {
 		/* Go to the specified directory. */
-		eel_gconf_set_locale_string (PREF_STARTUP_LOCATION, dir_urls[i]);
+		preferences_set_startup_location (dir_urls[i]);
 
 		current_window = window_new ();
 		gtk_widget_show (current_window->app);
@@ -439,31 +458,6 @@ all_windows_update_bookmark_list ()
 }
 
 
-void 
-all_windows_update_viewer_options ()
-{
-	GList *scan;
-
-	for (scan = window_list; scan; scan = scan->next) {
-		GThumbWindow *window = scan->data;
-
-		image_viewer_set_check_type   (IMAGE_VIEWER (window->viewer),
-					       pref_get_check_type ());
-		image_viewer_set_check_size   (IMAGE_VIEWER (window->viewer),
-					       pref_get_check_size ());
-		image_viewer_set_transp_type  (IMAGE_VIEWER (window->viewer),
-					       pref_get_transp_type ());
-		image_viewer_set_zoom_quality (IMAGE_VIEWER (window->viewer),
-					       pref_get_zoom_quality ());
-		image_viewer_set_zoom_change  (IMAGE_VIEWER (window->viewer),
-					       pref_get_zoom_change ());
-		image_viewer_update_view      (IMAGE_VIEWER (window->viewer));
-
-		window_sync_menu_with_preferences (window);
-	}
-}
-
-
 void 
 all_windows_update_browser_options ()
 {
@@ -472,8 +466,8 @@ all_windows_update_browser_options ()
 	for (scan = window_list; scan; scan = scan->next) {
 		GThumbWindow  *window = scan->data;
 		
-		window->file_list->enable_thumbs = eel_gconf_get_boolean (PREF_SHOW_THUMBNAILS);
-		gth_file_list_set_thumbs_size (window->file_list, eel_gconf_get_integer (PREF_THUMBNAIL_SIZE));
+		window->file_list->enable_thumbs = eel_gconf_get_boolean (PREF_SHOW_THUMBNAILS, TRUE);
+		gth_file_list_set_thumbs_size (window->file_list, eel_gconf_get_integer (PREF_THUMBNAIL_SIZE, 95));
 		gth_file_view_set_view_mode (window->file_list->view,
 					     pref_get_view_mode ());
 		window_update_file_list (window);
@@ -954,7 +948,7 @@ load_session (void)
 		location = gnome_config_get_string (key);
 		g_free (key);
 
-		eel_gconf_set_locale_string (PREF_STARTUP_LOCATION, location);
+		preferences_set_startup_location (location);
 
 		window = window_new ();
 		gtk_widget_show (window->app);
